==> svm-1.0.0-rc16-sources.jar: com/oracle/svm/core/heap/GC.java <==
/*
 * Copyright (c) 2015, 2017, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.oracle.svm.core.heap;

import java.lang.management.GarbageCollectorMXBean;
import java.util.List;

public interface GC {

    /** Cause a collection of the Heap's choosing. */
    void collect(String cause);

    /** Cause a full collection. */
    void collectCompletely(String cause);

    /*
     * Registered walkers of object reference roots. Since these walkers are used during collection,
     * they must not move, either by being in the image heap, or by being pinned.
     */

    void registerObjectReferenceWalker(ObjectReferenceWalker walker);

    void unregisterObjectReferenceWalker(ObjectReferenceWalker walker);

    /*
     * Registered collection watchers.
     */

    void registerCollectionWatcher(CollectionWatcher watcher);

    void unregisterCollectionWatcher(CollectionWatcher watcher);

    /** Get the list of GarbageCollectorMXBeans for this collector. */
    List<GarbageCollectorMXBean> getGarbageCollectorMXBeanList();
}

==> svm-19.3.0-sources.jar: com/oracle/svm/core/heap/GC.java <==
/*
 * Copyright (c) 2015, 2017, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.oracle.svm.core.heap;

import java.lang.management.GarbageCollectorMXBean;
import java.util.List;

public interface GC {

    /** Cause a collection of the Heap's choosing. */
    void collect(GCCause cause);

    /** Cause a full collection. */
    void collectCompletely(GCCause cause);

    /*
     * Registered collection watchers.
     */

    void registerCollectionWatcher(CollectionWatcher watcher);

    void unregisterCollectionWatcher(CollectionWatcher watcher);

    /** Get the list of GarbageCollectorMXBeans for this collector. */
    List<GarbageCollectorMXBean> getGarbageCollectorMXBeanList();
}
